@@ -27,6 +27,8 @@
  *
  */
 
+use OCP\Util;
+
 \OCA\Files_Sharing\Helper::registerHooks();
 
 \OCP\Share::registerBackend('file', 'OCA\Files_Sharing\ShareBackend\File');
@@ -34,33 +36,36 @@
 
 $application = new \OCA\Files_Sharing\AppInfo\Application();
 $application->registerMountProviders();
+$application->registerNotifier();
+$application->registerEvents();
 
+// TODO: move to "Hooks" class
 $eventDispatcher = \OC::$server->getEventDispatcher();
 $eventDispatcher->addListener(
 	'OCA\Files::loadAdditionalScripts',
-	function() {
-		\OCP\Util::addScript('files_sharing', 'share');
-		\OCP\Util::addScript('files_sharing', 'sharetabview');
+	function () {
+		Util::addScript('files_sharing', 'share');
+		Util::addScript('files_sharing', 'sharetabview');
+		Util::addScript('files_sharing', 'sharedialogview');
 		if (\OC::$server->getConfig()->getAppValue('files_sharing', 'incoming_server2server_share_enabled', 'yes') === 'yes') {
-			\OCP\Util::addScript('files_sharing', 'external');
+			Util::addScript('files_sharing', 'external');
 		}
-		\OCP\Util::addStyle('files_sharing', 'sharetabview');
+		Util::addStyle('files_sharing', 'sharetabview');
 	}
 );
 
 // \OCP\Util::addStyle('files_sharing', 'sharetabview');
 
-\OC::$server->getActivityManager()->registerExtension(function() {
-		return new \OCA\Files_Sharing\Activity(
-			\OC::$server->query('L10NFactory'),
-			\OC::$server->getURLGenerator(),
-			\OC::$server->getActivityManager()
-		);
+\OC::$server->getActivityManager()->registerExtension(function () {
+	return new \OCA\Files_Sharing\Activity(
+		\OC::$server->query('L10NFactory'),
+		\OC::$server->getURLGenerator(),
+		\OC::$server->getActivityManager()
+	);
 });
 
 $config = \OC::$server->getConfig();
-if (class_exists('OCA\Files\App') && $config->getAppValue('core', 'shareapi_enabled', 'yes') === 'yes') {
-
+if (\class_exists('OCA\Files\App') && $config->getAppValue('core', 'shareapi_enabled', 'yes') === 'yes') {
 	\OCA\Files\App::getNavigationManager()->add(function () {
 		$l = \OC::$server->getL10N('files_sharing');
 		return [
@@ -72,8 +77,7 @@ if (class_exists('OCA\Files\App') && $config->getAppValue('core', 'shareapi_enab
 		];
 	});
 
-	if (\OCP\Util::isSharingDisabledForUser() === false) {
-
+	if (Util::isSharingDisabledForUser() === false) {
 		\OCA\Files\App::getNavigationManager()->add(function () {
 			$l = \OC::$server->getL10N('files_sharing');
 			return [
