@@ -36,6 +36,7 @@ use \OCP\IURLGenerator;
 use \OCP\IRequest;
 use \OCP\IL10N;
 use \OCP\IConfig;
+use OCP\IUser;
 use OCP\IUserManager;
 use OCP\Mail\IMailer;
 use OCP\Security\ISecureRandom;
@@ -50,7 +51,6 @@ use OC\User\Session;
  * @package OC\Core\Controller
  */
 class LostController extends Controller {
-
 	/** @var IURLGenerator */
 	protected $urlGenerator;
 	/** @var IUserManager */
@@ -93,20 +93,22 @@ class LostController extends Controller {
 	 * @param ILogger $logger
 	 * @param Session $userSession
 	 */
-	public function __construct($appName,
-								IRequest $request,
-								IURLGenerator $urlGenerator,
-								IUserManager $userManager,
-								OC_Defaults $defaults,
-								IL10N $l10n,
-								IConfig $config,
-								ISecureRandom $secureRandom,
-								$from,
-								$isDataEncrypted,
-								IMailer $mailer,
-								ITimeFactory $timeFactory,
-								ILogger $logger,
-								Session $userSession) {
+	public function __construct(
+		$appName,
+		IRequest $request,
+		IURLGenerator $urlGenerator,
+		IUserManager $userManager,
+		OC_Defaults $defaults,
+		IL10N $l10n,
+		IConfig $config,
+		ISecureRandom $secureRandom,
+		$from,
+		$isDataEncrypted,
+		IMailer $mailer,
+		ITimeFactory $timeFactory,
+		ILogger $logger,
+		Session $userSession
+	) {
 		parent::__construct($appName, $request);
 		$this->urlGenerator = $urlGenerator;
 		$this->userManager = $userManager;
@@ -137,7 +139,9 @@ class LostController extends Controller {
 			$this->checkPasswordResetToken($token, $userId);
 		} catch (\Exception $e) {
 			return new TemplateResponse(
-				'core', 'error', [
+				'core',
+				'error',
+				[
 					"errors" => [["error" => $e->getMessage()]]
 				],
 				'guest'
@@ -162,8 +166,8 @@ class LostController extends Controller {
 	private function checkPasswordResetToken($token, $userId) {
 		$user = $this->userManager->get($userId);
 
-		$splittedToken = explode(':', $this->config->getUserValue($userId, 'owncloud', 'lostpassword', null));
-		if(count($splittedToken) !== 2) {
+		$splittedToken = \explode(':', $this->config->getUserValue($userId, 'owncloud', 'lostpassword', null));
+		if (\count($splittedToken) !== 2) {
 			$this->config->deleteUserValue($userId, 'owncloud', 'lostpassword');
 			throw new \Exception($this->l10n->t('Could not reset password because the token is invalid'));
 		}
@@ -174,7 +178,7 @@ class LostController extends Controller {
 			throw new \Exception($this->l10n->t('Could not reset password because the token expired'));
 		}
 
-		if (!hash_equals($splittedToken[1], $token)) {
+		if (!\hash_equals($splittedToken[1], $token)) {
 			$this->config->deleteUserValue($userId, 'owncloud', 'lostpassword');
 			throw new \Exception($this->l10n->t('Could not reset password because the token does not match'));
 		}
@@ -186,7 +190,7 @@ class LostController extends Controller {
 	 * @return array
 	 */
 	private function error($message, array $additional= []) {
-		return array_merge(['status' => 'error', 'msg' => $message], $additional);
+		return \array_merge(['status' => 'error', 'msg' => \htmlspecialchars($message)], $additional);
 	}
 
 	/**
@@ -202,11 +206,28 @@ class LostController extends Controller {
 	 * @param string $user
 	 * @return array
 	 */
-	public function email($user){
+	public function email($user) {
+		try {
+			$userObject = $this->userManager->get($user);
+			if ($userObject === null) {
+				$users = $this->userManager->getByEmail($user);
+				// we only allow login by email if unique
+				if (\count($users) === 1) {
+					$user = $users[0]->getUID();
+				}
+			}
+			if ($userObject instanceof IUser) {
+				$user = $userObject->getUID();
+			}
+		} catch (\Exception $e) {
+			// Do not disclose any information during User lookup
+			return $this->success();
+		}
 		// FIXME: use HTTP error codes
 		try {
-			$this->sendEmail($user);
-		} catch (\Exception $e){
+			list($link, $token) = $this->generateTokenAndLink($user);
+			$this->sendEmail($user, $token, $link);
+		} catch (\Exception $e) {
 			return $this->error($e->getMessage());
 		}
 
@@ -236,13 +257,13 @@ class LostController extends Controller {
 
 			\OC_Hook::emit('\OC\Core\LostPassword\Controller\LostController', 'post_passwordReset', ['uid' => $userId, 'password' => $password]);
 			@\OC_User::unsetMagicInCookie();
-		} catch (\Exception $e){
+		} catch (\Exception $e) {
 			return $this->error($e->getMessage());
 		}
 
 		try {
 			$this->sendNotificationMail($userId);
-		} catch (\Exception $e){
+		} catch (\Exception $e) {
 			return $this->error($e->getMessage());
 		}
 
@@ -251,7 +272,6 @@ class LostController extends Controller {
 		return $this->success();
 	}
 
-
 	/**
 	 * @param string $userId
 	 * @throws \Exception
@@ -259,16 +279,20 @@ class LostController extends Controller {
 	protected function sendNotificationMail($userId) {
 		$user = $this->userManager->get($userId);
 		$email = $user->getEMailAddress();
+		$name = $user->getDisplayName();
 
 		if ($email !== '') {
 			$tmpl = new \OC_Template('core', 'lostpassword/notify');
 			$msg = $tmpl->fetchPage();
+			$tmplAlt = new \OC_Template('core', 'lostpassword/altnotify');
+			$msgAlt = $tmplAlt->fetchPage();
 
 			try {
 				$message = $this->mailer->createMessage();
-				$message->setTo([$email => $userId]);
+				$message->setTo([$email => $name]);
 				$message->setSubject($this->l10n->t('%s password changed successfully', [$this->defaults->getName()]));
-				$message->setPlainBody($msg);
+				$message->setPlainBody($msgAlt);
+				$message->setHtmlBody($msg);
 				$message->setFrom([$this->from => $this->defaults->getName()]);
 				$this->mailer->send($message);
 			} catch (\Exception $e) {
@@ -279,12 +303,30 @@ class LostController extends Controller {
 		}
 	}
 
+	/**
+	 * @param string $userId
+	 * @return array
+	 */
+	public function generateTokenAndLink($userId) {
+		$token = $this->secureRandom->generate(
+			21,
+			ISecureRandom::CHAR_DIGITS .
+			ISecureRandom::CHAR_LOWER .
+			ISecureRandom::CHAR_UPPER
+		);
+
+		$link = $this->urlGenerator->linkToRouteAbsolute('core.lost.resetform', ['userId' => $userId, 'token' => $token]);
+		return [$link, $token];
+	}
+
 	/**
 	 * @param string $user
+	 * @param string $token
+	 * @param string $link
 	 * @throws \Exception
 	 * @return boolean
 	 */
-	protected function sendEmail($user) {
+	public function sendEmail($user, $token, $link) {
 		if ($this->userManager->userExists($user)) {
 			$userObject = $this->userManager->get($user);
 			$email = $userObject->getEMailAddress();
@@ -296,14 +338,15 @@ class LostController extends Controller {
 		} else {
 			$users = $this->userManager->getByEmail($user);
 
-			switch (count($users)) {
+			switch (\count($users)) {
 				case 0:
 					$this->logger->error('Could not send reset email because User does not exist. User: {user}', ['app' => 'core', 'user' => $user]);
 					return false;
 				case 1:
 					$this->logger->info('User with input as email address found. User: {user}', ['app' => 'core', 'user' => $user]);
-					$email = $users[0]->getEMailAddress();
-					$user = $users[0]->getUID();
+					$userObject = $users[0];
+					$email = $userObject->getEMailAddress();
+					$user = $userObject->getUID();
 					break;
 				default:
 					$this->logger->error('Could not send reset email because the email id is not unique. User: {user}', ['app' => 'core', 'user' => $user]);
@@ -311,32 +354,31 @@ class LostController extends Controller {
 			}
 		}
 
-		$token = $this->config->getUserValue($user, 'owncloud', 'lostpassword');
-		if ($token !== '') {
-			$splittedToken = explode(':', $token);
-			if ((count($splittedToken)) === 2 && $splittedToken[0] > ($this->timeFactory->getTime() - 60 * 5)) {
+		$getToken = $this->config->getUserValue($user, 'owncloud', 'lostpassword');
+		if ($getToken !== '') {
+			$splittedToken = \explode(':', $getToken);
+			if ((\count($splittedToken)) === 2 && $splittedToken[0] > ($this->timeFactory->getTime() - 60 * 5)) {
 				$this->logger->alert('The email is not sent because a password reset email was sent recently.');
 				return false;
 			}
 		}
 
-		$token = $this->secureRandom->generate(21,
-			ISecureRandom::CHAR_DIGITS .
-			ISecureRandom::CHAR_LOWER .
-			ISecureRandom::CHAR_UPPER);
 		$this->config->setUserValue($user, 'owncloud', 'lostpassword', $this->timeFactory->getTime() . ':' . $token);
 
-		$link = $this->urlGenerator->linkToRouteAbsolute('core.lost.resetform', ['userId' => $user, 'token' => $token]);
-
 		$tmpl = new \OC_Template('core', 'lostpassword/email');
 		$tmpl->assign('link', $link);
 		$msg = $tmpl->fetchPage();
+		$tmplAlt = new \OC_Template('core', 'lostpassword/altemail');
+		$tmplAlt->assign('link', $link);
+		$msgAlt = $tmplAlt->fetchPage();
+		$name = $userObject->getDisplayName();
 
 		try {
 			$message = $this->mailer->createMessage();
-			$message->setTo([$email => $user]);
+			$message->setTo([$email => $name]);
 			$message->setSubject($this->l10n->t('%s password reset', [$this->defaults->getName()]));
-			$message->setPlainBody($msg);
+			$message->setPlainBody($msgAlt);
+			$message->setHtmlBody($msg);
 			$message->setFrom([$this->from => $this->defaults->getName()]);
 			$this->mailer->send($message);
 		} catch (\Exception $e) {
@@ -350,10 +392,9 @@ class LostController extends Controller {
 
 	private function logout() {
 		$loginToken = $this->request->getCookie('oc_token');
-		if (!is_null($loginToken)) {
+		if ($loginToken !== null) {
 			$this->config->deleteUserValue($this->userSession->getUser()->getUID(), 'login_token', $loginToken);
 		}
 		$this->userSession->logout();
 	}
-
 }
