@@ -1,6 +1,7 @@
 OC.L10N.register(
     "core",
     {
+    "Please select a file." : "Silakan pilih sebuah berkas.",
     "File is too big" : "Berkas terlalu besar",
     "Invalid file provided" : "Berkas yang diberikan tidak sah",
     "No image or file provided" : "Tidak ada gambar atau berkas yang disediakan",
@@ -11,17 +12,29 @@ OC.L10N.register(
     "No crop data provided" : "Tidak ada data krop tersedia",
     "No valid crop data provided" : "Tidak ada data valid untuk dipangkas",
     "Crop is not square" : "Pangkas ini tidak persegi",
-    "Couldn't reset password because the token is invalid" : "Tidak dapat menyetel ulang sandi karena token tidak sah",
-    "Couldn't reset password because the token is expired" : "Tidak dapat menyetel ulang sandi karena token telah kadaluarsa",
+    "Could not reset password because the token is invalid" : "Tidak dapat menyetel ulang sandi karena token tidak sah",
+    "Could not reset password because the token expired" : "Tidak dapat menyetel ulang sandi karena token kedaluwarsa",
+    "Could not reset password because the token does not match" : "Tidak dapat menyetel ulang sandi karena token tidak cocok",
+    "%s password changed successfully" : "%s sandi sukses diubah",
     "%s password reset" : "%s sandi disetel ulang",
     "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim email setel ulang. Silakan hubungi administrator Anda.",
-    "Couldn't send mail to following users: %s " : "Tidak dapat mengirim Email ke pengguna berikut: %s",
+    "Download / View" : "Unduh / Lihat",
+    "Recipients can view or download contents." : "Penerima dapat melihat atau mengunduh konten.",
+    "Download / View / Upload" : "Unduh / Lihat / Unggah",
+    "Recipients can view, download and upload contents." : "Penerima dapat melihat, mengunduh, dan mengunggah konten.",
+    "Download / View / Edit" : "Unduh / Lihat / Sunting",
+    "Recipients can view, download, edit, delete and upload contents." : "Penerima dapat melihat, mengunduh, menyunting, dan mengunggah konten.",
+    "Upload only" : "Unggah saja",
+    "Receive files from multiple recipients without revealing the contents of the folder." : "Terima data dari beragam pengirim tanpa mengungkapkan konten dari foldernya.",
     "Preparing update" : "Mempersiapkan pembaruan",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair warning: " : "Peringatan perbaikan:",
     "Repair error: " : "Kesalahan perbaikan:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Mohon menggunakan perintah baris pembaharuan karena pembaharuan otomatis dinonaktifkan dalam config.php.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Mengecek tabel %s",
     "Turned on maintenance mode" : "Hidupkan mode perawatan",
     "Turned off maintenance mode" : "Matikan mode perawatan",
-    "Maintenance mode is kept active" : "Mode Pemeliharaan masih aktif",
+    "Maintenance mode is kept active" : "Mode pemeliharaan dipertahankan aktif",
     "Updating database schema" : "Memperbarui skema basis data",
     "Updated database" : "Basis data terbaru",
     "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema basis data dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
@@ -30,6 +43,10 @@ OC.L10N.register(
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema untuk %s dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
     "Checked database schema update for apps" : "Pembaruan skema basis data terperiksa untuk aplikasi",
     "Updated \"%s\" to %s" : "Terbaru \"%s\" sampai %s",
+    "Set log level to debug" : "Mengeset tingkat log untuk debug",
+    "Reset log level" : "Menyetel ulang tingkat log",
+    "Starting code integrity check" : "Mulai mengecek kode integritas",
+    "Finished code integrity check" : "Selesai mengecek kode integritas",
     "%s (3rdparty)" : "%s (pihak ke-3)",
     "%s (incompatible)" : "%s (tidak kompatibel)",
     "Following apps have been disabled: %s" : "Aplikasi berikut telah dinonaktifkan: %s",
@@ -48,13 +65,13 @@ OC.L10N.register(
     "Thu." : "Kam.",
     "Fri." : "Jum.",
     "Sat." : "Sab.",
-    "Su" : "Min",
-    "Mo" : "Sen",
-    "Tu" : "Sel",
-    "We" : "Rab",
-    "Th" : "Kam",
-    "Fr" : "Jum",
-    "Sa" : "Sab",
+    "Su" : "Mg",
+    "Mo" : "Sn",
+    "Tu" : "Sl",
+    "We" : "Rb",
+    "Th" : "Km",
+    "Fr" : "Jm",
+    "Sa" : "Sb",
     "January" : "Januari",
     "February" : "Februari",
     "March" : "Maret",
@@ -79,7 +96,9 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Des.",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Terdapat masalah dengan pengecekan kode integritas. Informasi lebih lanjtu...</a>",
     "Settings" : "Pengaturan",
+    "Problem loading page, reloading in 5 seconds" : "Masalah dalam memuat halaman, memuat ulang dalam 5 detik",
     "Saving..." : "Menyimpan...",
     "Dismiss" : "Buang",
     "seconds ago" : "beberapa detik yang lalu",
@@ -87,6 +106,7 @@ OC.L10N.register(
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Berkas-berkas Anda terenkripsi. Jika Anda tidak mengaktifkan kunci pemulihan, tidak ada cara lain untuk mendapatkan data Anda kembali setelah sandi di setel ulang.<br />Jika Anda tidak yakin dengan apa yang akan Anda dilakukan, mohon hubungi administrator Anda sebelum melanjutkan. <br />Apakah Anda yakin ingin melanjutkan?",
     "I know what I'm doing" : "Saya tahu apa yang saya lakukan",
     "Password can not be changed. Please contact your administrator." : "Sandi tidak dapat diubah. Silakan hubungi administrator Anda",
+    "Error adding {addItem}: {addItem} already exists" : "Masalah menambahkan {addItem}: {addItem} sudah ada",
     "No" : "Tidak",
     "Yes" : "Ya",
     "Choose" : "Pilih",
@@ -111,10 +131,19 @@ OC.L10N.register(
     "Good password" : "Sandi baik",
     "Strong password" : "Sandi kuat",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Server web Anda belum diatur dengan benar untuk mengizinkan sinkronisasi berkas karena antarmuka WebDAV nampaknya rusak.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Server situs Anda tidak di pasang dengan betul untuk mengatasi \"{url}\". Untuk informasi lebih lanjut dapat ditemukan dalam <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasi</a> kami.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Server ini tidak tersambung ke internet. Ini berarti beberapa fitur seperti me-mount penyimpanan eksternal, notifikasi pembaruan atau instalasi aplikasi pihak ketiga tidak akan bekerja. Mengakses berkas secara remote dan mengirim notifikasi email juga tidak bekerja. Kami menyarankan untuk mengaktifkan koneksi internet untuk server ini jika Anda ingin memiliki fitur ini.",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Tidak ada cache memori yang sudah dikonfigurasi. Untuk meningkatkan performa Anda mohon konfigurasi sebuah memcache jika tersedia. Informasi lebih lanjut dapat ditemukan dalam <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasi</a> kami.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom tidak dapat dibaca oleh PHP yang mana sangat tidak dianjurkan untuk alasan keamanan. Informasi lebih lanjut dapat ditemukan dalam <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasi</a> kami.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Anda saat ini menjalankan PHP {versi}. Kami menyarankan Anda untuk meningkatkan versi PHP anda untuk memanfaatkan <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">pembaharuan performa dan keamanan yang disediadakan oleh PHP Group</a> segera saat distribusi anda mendukungnya.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Konfigurasi pengembalian awalan proxy tidak betul, atau anda mengakses ownCloud dari proxy terpercaya. Jika anda tidak mengakses ownCloud dari sebuah proxy terpercaya, ini merupakan masalah keamanan dan dapat memperbolehkan penyerang untuk menipu alamat IP mereka agar diperbolehkan oleh ownCloud. Informasi lebih lanjut dapat ditemukan dalam <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasi</a> kami.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcache dikonfigurasi sebagai cache distribusi, namun modul \"memcache\" PHP yang salah telah diinstal. \\OC\\Memcache\\Memcached hanya mendukung \"memcached\" dan bukan \"memcache\". Lihat <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">Wiki memcached tentang kedua modul tersebut</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Beberapa data tidak dapat melewati cek integritas. Keterangan lebih lanjut tentang bagaimana mengatasi isu ini dapat ditemukan dalam <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentasi</a> kami. (<a href=\"{codeIntegrityDownloadEndpoint}\">daftar data tidak valid...</a> / <a href=\"{rescanEndpoint}\">Scan ulang...</a>)",
+    "You are running in DEBUG mode, this can cause unwanted side effects. Please remove the \"debug\" flag from \"config.php\"." : "Anda berada dalam mode DEBUG, hal ini dapat menyebabkan efek samping yang tidak diinginkan. Mohon hapus bendera \"debug\" dalam \"config.php\".",
     "Error occurred while checking server setup" : "Kesalahan tidak terduga saat memeriksa setelan server",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Direktori data dan berkas Anda kemungkinan dapat diakses dari Internet. Berkas .htaccess tidak bekerja. Kami sangat menyarankan Anda untuk mengkonfigurasi server web agar direktori data tidak lagi dapat diakses atau pindahkan direktori data Anda di luar root dokumen server web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Header HTTP \"{header}\" tidak dikonfigurasi sama dengan \"{expected}\". Hal ini berpotensi pada resiko keamanan dan privasi. Kami sarankan untuk menyesuaikan pengaturan ini.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "Header HTTP \"Strictt-Transport-Security\" tidak dikonfigurasi pada setidaknya \"{detik}\" detik. Untuk meningkatkan keamanan kami merekomendasikan mengaktifkan HSTS sesuai penjelasan dalam <a href=\"{docUrl}\" rel=\"noreferrer\">tips kemanan</a> kami.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Anda mengakses situs ini via HTTP. Kami sangat menyarankan Anda untuk mengatur server Anda menggunakan HTTPS yang dibahas di <a href=\"{docUrl}\">tips keamanan</a> kami.",
     "Shared" : "Dibagikan",
     "Shared with {recipients}" : "Dibagikan dengan {recipients}",
@@ -122,26 +151,49 @@ OC.L10N.register(
     "Error while sharing" : "Kesalahan saat membagikan",
     "Error while unsharing" : "Kesalahan saat membatalkan pembagian",
     "The public link will expire no later than {days} days after it is created" : "Tautan publik akan kadaluarsa tidak lebih dari {days} hari setelah ini dibuat",
-    "Set expiration date" : "Atur tanggal kedaluwarsa",
     "Expiration" : "Kedaluwarsa",
-    "Expiration date" : "Tanggal kedaluwarsa",
+    "Choose an expiration date" : "Pilih tanggal kadaluarsa",
+    "Expiration date is required" : "Tanggal kadaluarsa dibutuhkan",
+    "Delete {link}" : "Hapus {tautan}",
+    "Remove link" : "Hapus tautan",
     "Link" : "Tautan",
+    "Create public link" : "Buat tautan publik",
     "Edit" : "Sunting",
     "Remove" : "Hapus",
-    "Choose a password for the public link" : "Tetapkan sandi untuk tautan publik",
+    "Copy to clipboard" : "Salin ke klipbor",
+    "Social share" : "Pembagian sosial ",
+    "There are currently no link shares, you can create one" : "Saat ini tidak terdapat tautan dibagi, buat sekarang",
+    "Anyone with the link has access to the file/folder" : "Siapapun yang mengetahui tautan memiliki akses ke berkas/ folder",
+    "Copied!" : "Dicopy!",
+    "Not supported!" : "Tidak didukung!",
+    "Press ⌘-C to copy." : "Tekan ⌘-C untuk meng-copy",
+    "Press Ctrl-C to copy." : "Tekan Ctrl-C untuk meng-copy",
+    "Password required" : "Kata sandi dibutuhkan",
+    "Link name" : "Nama tautan",
+    "Name" : "Nama",
     "Filename" : "Nama berkas",
     "Password" : "Sandi",
-    "Name" : "Nama",
-    "Allow editing" : "Izinkan penyuntingan",
+    "Recipients can view, download and edit contents." : "Penerima dapat melihat, mengunduh, dan menyunting konten.",
+    "Can not remove required password" : "Tidak dapat menghilangkan kata sandi yang dibutuhkan",
+    "Edit link share: {name}" : "Sunting tautan yang dibagi: {nama}",
+    "Create link share: {name}" : "Buat tautan yang dibagi: {nama}",
+    "Share" : "Bagikan",
     "Save" : "Simpan",
-    "Error while sending notification" : "Kesalahan ketika mengirim notifikasi",
-    "Sending ..." : "Mengirim ...",
-    "Email sent" : "Email terkirim",
+    "Remove password" : "Hilangkan kata sandi",
+    "Share to Twitter. Opens in a new window." : "Bagikan ke Twitter. Buka di sebuah tingkap baru.",
+    "Share to Facebook. Opens in a new window." : "Bagikan ke Facebook. Buka dalam sebuah tingkap baru.",
+    "Share to Diaspora. Opens in a new window." : "Bagikan ke Diaspora. Buka dalam sebuah tingkap baru.",
+    "Share via email. Opens your mail client." : "Bagikan melalui surel. Buka dalam klien surat anda.",
     "Email link to person" : "Emailkan tautan ini ke orang",
+    "Send copy to self" : "Kirimkan copy ke diri sendiri",
+    "Send link via email" : "Kirimkan tautan melalui surel",
+    "Add personal message" : "Tambah pesan personal",
+    "Sending" : "Mengirim",
+    "E-Mail sent" : "Surel sudah dikirim",
     "Shared with you and the group {group} by {owner}" : "Dibagikan dengan anda dan grup {group} oleh {owner}",
     "Shared with you by {owner}" : "Dibagikan dengan anda oleh {owner}",
     "group" : "grup",
-    "remote" : "remote",
+    "federated" : "Menyatukan",
     "notify by email" : "notifikasi via email",
     "Unshare" : "Batalkan berbagi",
     "can share" : "dapat berbagi",
@@ -150,13 +202,31 @@ OC.L10N.register(
     "change" : "ubah",
     "delete" : "hapus",
     "access control" : "kontrol akses",
+    "Could not unshare" : "Tidak dapat batalkan berbagi",
+    "Email notification was sent!" : "Notifikasi surel sudah dikirim!",
+    "Email notification not sent" : "Notifikasi surel tidak terkirim",
     "Share details could not be loaded for this item." : "Rincian berbagi tidak dapat dimuat untuk item ini.",
-    "Share" : "Bagikan",
-    "Resharing is not allowed" : "Berbagi ulang tidak diizinkan",
+    "No users or groups found for {search}" : "Tidak ada pengguna atau grup ditemukan untuk {pencarian}",
+    "No users found for {search}" : "Tidak ada pengguna ditemukan untuk {pencarian}",
+    "_Please enter at least {chars} character for suggestions_::_Please enter at least {chars} characters for suggestions_" : ["Mohon masukkan setidaknya {karakter} karakter untuk petunjuk"],
+    "An error occurred. Please try again" : "Terjadi kesalahan. Mohon coba lagi",
+    "User" : "Pengguna",
+    "Group" : "Grup",
+    "User and Groups" : "Pengguna dan grup",
+    "Public Links" : "Tautan Publik",
+    "Sharing is not allowed" : "Pembagian tidak diperbolehkan",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Bagikan dengan orang lain di ownCloud menggunakan sintaks username@example.com/owncloud",
-    "Warning" : "Peringatan",
-    "Delete" : "Hapus",
+    "Share with users…" : "Bagikan dengan pengguna...",
+    "Share with users or groups…" : "Bagi dengan pengguna atau grup...",
+    "Error removing share" : "Kesalahan menghilangkan pembagian",
+    "Non-existing tag #{tag}" : "tag #{tag} tidak ada",
+    "restricted" : "dibatasi",
+    "invisible" : "tidak terlihat",
+    "Static" : "Statis",
+    "({scope})" : "({scope})",
     "Rename" : "Ubah nama",
+    "Delete" : "Hapus",
+    "Collaborative tags" : "Tag gabungan",
     "The object type is not specified." : "Tipe objek tidak ditentukan.",
     "Enter new" : "Masukkan baru",
     "Add" : "Tambah",
@@ -168,10 +238,13 @@ OC.L10N.register(
     "sunny" : "cerah",
     "Hello {name}, the weather is {weather}" : "Helo {name}, jepang {weather}",
     "Hello {name}" : "Helo {name}",
+    "new" : "baru",
     "_download %n file_::_download %n files_" : ["unduh %n berkas"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Pembaruan sedang dalam proses, meninggalkan halaman ini mungkin dapat mengganggu proses di beberapa lingkungan.",
+    "Updating to {version}" : "Pembaharuan ke {versi}",
     "An error occurred." : "Terjadi kesalahan.",
     "Please reload the page." : "Silakan muat ulang halaman.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Perbaharuan tidak berhasil. Informasi lebih lanjut <a href=\"{url}\">cek post forum kami</a> yang membahas isu ini.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Pembaruan gagal. Silakan laporkan masalah ini ke <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">komunitas ownCloud</a>.",
     "The update was successful. There were warnings." : "Pembaruan telah berhasil. Terdapat peringatan.",
     "The update was successful. Redirecting you to ownCloud now." : "Pembaruan sukses. Anda akan diarahkan ulang ke ownCloud.",
@@ -189,11 +262,12 @@ OC.L10N.register(
     "You can click here to return to %s." : "Anda dapat klik disini unutk kembali ke %s.",
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hai,\n\nhanya supaya anda tahu bahwa %s membagikan %s dengan anda.\nLihat: %s\n\n",
     "The share will expire on %s." : "Pembagian akan berakhir pada %s.",
+    "Personal note from the sender: \n %s." : "Catatan personal dari pengirim:\n%s.",
     "Cheers!" : "Horee!",
     "Internal Server Error" : "Kesalahan Server Internal",
     "The server encountered an internal error and was unable to complete your request." : "Server mengalami kesalahan internal dan tidak dapat menyelesaikan permintaan Anda.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Silahkan hubungi administrator server jika kesalahan ini muncul kembali berulang kali, harap sertakan rincian teknis di bawah ini dalam laporan Anda.",
-    "More details can be found in the server log." : "Rincian lebih lengkap dapat ditemukan di log server.",
+    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Mohon hubungi admin server jika kesalahan terus muncul beberapa kali dan masukkan detil teknis dibawah ini dalam laporan Anda.",
+    "More details can be found in the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server log</a>." : "Detil lebih lanjut dapat ditemukan dalam <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">log server</a>.",
     "Technical details" : "Rincian teknis",
     "Remote Address: %s" : "Alamat remote: %s",
     "Request ID: %s" : "ID Permintaan: %s",
@@ -203,6 +277,8 @@ OC.L10N.register(
     "File: %s" : "Berkas: %s",
     "Line: %s" : "Baris: %s",
     "Trace" : "Jejak",
+    "Imprint" : "Jejak",
+    "Privacy Policy" : "Peraturan Kebijakan",
     "Create an <strong>admin account</strong>" : "Buat sebuah <strong>akun admin</strong>",
     "Username" : "Nama pengguna",
     "Storage & database" : "Penyimpanan & Basis data",
@@ -221,31 +297,29 @@ OC.L10N.register(
     "For larger installations we recommend to choose a different database backend." : "Untuk instalasi yang lebih besar, kami menyarankan untuk memilih backend basis data yang berbeda.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Terutama saat menggunakan klien desktop untuk sinkronisasi berkas, penggunaan SQLite tidak disarankan.",
     "Finish setup" : "Selesaikan instalasi",
-    "Finishing …" : "Menyelesaikan ...",
     "Need help?" : "Butuh bantuan?",
     "See the documentation" : "Lihat dokumentasi",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hai,<br><br>hanya memberi tahu jika %s membagikan <strong>%s</strong> dengan Anda.<br><a href=\"%s\">Lihat!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikasi ini memerlukan JavaScript untuk dapat beroperasi dengan benar. Mohon {linkstart}aktifkan JavaScript{linkend} dan muat ulang halaman ini.",
+    "Menu" : "Menu",
     "Log out" : "Keluar",
     "Search" : "Cari",
     "Server side authentication failed!" : "Otentikasi dari sisi server gagal!",
     "Please contact your administrator." : "Silahkan hubungi administrator anda.",
     "Please try again or contact your administrator." : "Mohon coba lagi atau hubungi administrator Anda.",
-    "Log in" : "Masuk",
+    "Login" : "Masuk",
     "Wrong password. Reset it?" : "Sandi salah. Atur ulang?",
+    "Wrong password." : "Kata sandi salah",
     "Stay logged in" : "Tetap masuk",
     "Alternative Logins" : "Cara Alternatif untuk Masuk",
     "Use the following link to reset your password: {link}" : "Gunakan tautan berikut untuk menyetel ulang sandi Anda: {link}",
     "New password" : "Sandi baru",
-    "New Password" : "Sandi Baru",
+    "Confirm Password" : "Konfirmasi Sandi",
     "Reset password" : "Setel ulang sandi",
     "This ownCloud instance is currently in single user mode." : "ownCloud ini sedang dalam mode pengguna tunggal.",
     "This means only administrators can use the instance." : "Ini berarti hanya administrator yang dapat menggunakan ownCloud.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hubungi administrator sistem anda jika pesan ini terus muncul atau muncul tiba-tiba.",
     "Thank you for your patience." : "Terima kasih atas kesabaran anda.",
-    "You are accessing the server from an untrusted domain." : "Anda mengakses server dari domain yang tidak terpercaya.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Tergantung pada konfigurasi Anda, sebagai seorang administrator Anda kemungkinan dapat menggunakan tombol bawah untuk mempercayai domain ini.",
-    "Add \"%s\" as trusted domain" : "tambahkan \"%s\" sebagai domain terpercaya",
     "App update required" : "Diperlukan perbarui aplikasi",
     "%s will be updated to version %s" : "%s akan diperbaarui ke versi %s",
     "These apps will be updated:" : "Aplikasi berikut akan diperbarui:",
@@ -254,11 +328,6 @@ OC.L10N.register(
     "Start update" : "Jalankan pembaruan",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Untuk menghindari waktu habis dengan instalasi yang lebih besar, Anda bisa menjalankan perintah berikut dari direktori instalasi Anda:",
     "This %s instance is currently in maintenance mode, which may take a while." : "Instansi %s ini sedang dalam modus pemeliharaan, mungkin memerlukan beberapa saat.",
-    "This page will refresh itself when the %s instance is available again." : "Halaman ini akan disegarkan dengan sendiri saat instansi %s tersebut tersedia kembali.",
-    "Remove link" : "Hapus tautan",
-    "Copy to clipboard" : "Salin ke klipbor",
-    "Anyone with the link has access to the file/folder" : "Siapapun yang mengetahui tautan memiliki akses ke berkas/ folder",
-    "Menu" : "Menu",
-    "Link name" : "Nama tautan"
+    "This page will refresh itself when the %s instance is available again." : "Halaman ini akan disegarkan dengan sendiri saat instansi %s tersebut tersedia kembali."
 },
 "nplurals=1; plural=0;");
