@@ -107,7 +107,7 @@ OC.L10N.register(
     "Ok" : "CONFIRMAR",
     "Error loading message template: {error}" : "Ocorreu um erro ao carregar o modelo: {error}",
     "read-only" : "só de leitura",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de ficheiro","{count} conflitos de ficheiro"],
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de ficheiro","{count} conflitos de ficheiro","{count} conflitos de ficheiro"],
     "One file conflict" : "Um conflito de ficheiro",
     "New Files" : "Novos Ficheiros",
     "Already existing files" : "Ficheiros já existentes",
@@ -159,7 +159,6 @@ OC.L10N.register(
     "Not supported!" : "Não suportado!",
     "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
     "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
-    "Choose a password" : "Escolha uma palavra-passe",
     "Password required" : "Palavra-passe necessária",
     "Link name" : "Nome de hiperligação",
     "Name" : "Nome",
@@ -173,7 +172,6 @@ OC.L10N.register(
     "Share to Twitter. Opens in a new window." : "Partilhar no Twitter. Abre uma janela nova.",
     "Share to Facebook. Opens in a new window." : "Partilhar no Facebook. Abre uma janela nova.",
     "Share to Diaspora. Opens in a new window." : "Partilhar no Diaspora. Abre uma janela nova.",
-    "Share to Google+. Opens in a new window." : "Partilhar no Google+. Abre uma janela nova.",
     "Share via email. Opens your mail client." : "Partilhar através de e-mail. Abre o seu cliente de e-mail.",
     "Email link to person" : "Enviar hiperligação por mensagem para a pessoa",
     "Send link via email" : "Enviar hiperligação via correio eletrónico",
@@ -200,16 +198,14 @@ OC.L10N.register(
     "Public Links" : "Ligações públicas",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartilhe com as pessoas nas outras ownClouds utilizando a sintaxe username@example.com/owncloud",
     "Share with users…" : "Compartilhe com os utilizadores...",
-    "Share with users, groups or remote users…" : "Compartilhe com os utilizadores, grupos ou utilizadores remotos...",
     "Share with users or groups…" : "Compartilhe com os utilizadores ou grupos...",
-    "Share with users or remote users…" : "Compartilhe com os utilizadores ou utilizadores remotos...",
     "Error removing share" : "Erro ao remover partilha",
     "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
     "restricted" : "limitado",
     "invisible" : "invisível",
     "({scope})" : "({scope})",
-    "Delete" : "Eliminar",
     "Rename" : "Renomear",
+    "Delete" : "Eliminar",
     "Collaborative tags" : "Etiquetas colaborativas",
     "The object type is not specified." : "O tipo de objeto não está especificado.",
     "Enter new" : "Inserir novo",
@@ -223,7 +219,7 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Olá {name}, o tempo está {weather}",
     "Hello {name}" : "Olá {name}",
     "new" : "novo",
-    "_download %n file_::_download %n files_" : ["transferir %n ficheiro","transferir %n ficheiros"],
+    "_download %n file_::_download %n files_" : ["transferir %n ficheiro","transferir %n ficheiros","transferir %n ficheiros"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em curso. Se deixar esta página agora poderá interromper o processo em alguns ambientes.",
     "Updating to {version}" : "A atualizar para {version}",
     "An error occurred." : "Ocorreu um erro.",
@@ -234,7 +230,7 @@ OC.L10N.register(
     "The update was successful. Redirecting you to ownCloud now." : "A atualização foi bem sucedida. A redirecioná-lo agora para o ownCloud.",
     "Searching other places" : "A procurar noutros lugares",
     "No search results in other folders" : "Sem resultados de procura nas outras pastas",
-    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de procura noutra pasta","{count} resultados de procura noutras pastas"],
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de procura noutra pasta","{count} resultados de procura noutras pastas","{count} resultados de procura noutras pastas"],
     "Personal" : "Pessoal",
     "Users" : "Utilizadores",
     "Apps" : "Aplicações",
@@ -273,13 +269,11 @@ OC.L10N.register(
     "Database name" : "Nome da base de dados",
     "Database tablespace" : "Tablespace da base de dados",
     "Database host" : "Anfitrião da base de dados",
-    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Por favor, especifique o número da porta com o nome do anfitrião (exemplo, localhost: 5432).",
     "Performance warning" : "Aviso de Desempenho",
     "SQLite will be used as database." : "SQLite será utilizado como base de dados.",
     "For larger installations we recommend to choose a different database backend." : "Para instalações maiores, nós recomendamos que escolha uma interface de base de dados diferente.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "O uso de SQLite é desencorajado especialmente se estiver a pensar em dar uso ao cliente desktop para sincronizar os seus ficheiros no seu computador.",
     "Finish setup" : "Terminar consiguração",
-    "Finishing …" : "A terminar...",
     "Need help?" : "Precisa de ajuda?",
     "See the documentation" : "Consulte a documentação",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Olá,<br><br>apenas para informar que %s partilhou <strong>%s</strong> consigo.<br><a href=\"%s\">Consulte aqui!</a><br><br>",
@@ -300,7 +294,6 @@ OC.L10N.register(
     "Use the following link to reset your password: {link}" : "Utilize a seguinte hiperligação para repor a sua palavra-passe: {link}",
     "Password changed successfully" : "Palavra-passe alterada com sucesso",
     "New password" : "Nova palavra-passe",
-    "New Password" : "Nova palavra-passe",
     "Reset password" : "Repor palavra-passe",
     "This ownCloud instance is currently in single user mode." : "Esta instância do ownCloud está atualmente configurada no modo de único utilizador.",
     "This means only administrators can use the instance." : "Isto significa que apenas os administradores podem utilizar a instância.",
@@ -311,7 +304,6 @@ OC.L10N.register(
     "Cancel login" : "Cancelar entrada",
     "Please authenticate using the selected factor." : "Por favor, autentique utilizando um segundo fator.",
     "An error occurred while verifying the token" : "Ocorreu um erro durante a verificação do código",
-    "You are accessing the server from an untrusted domain." : "Está a aceder ao servidor a partir de um domínio que não é de confiança.",
     "App update required" : "É necessário atualizar a aplicação",
     "%s will be updated to version %s" : "%s será atualizada para a versão %s.",
     "These apps will be updated:" : "Estas aplicações irão ser atualizadas.",
@@ -320,9 +312,8 @@ OC.L10N.register(
     "Start update" : "Iniciar atualização",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos expirados com instalações maiores, em vez disso, pode executar o seguinte comando a partir da diretoria de instalação:",
     "Detailed logs" : "Registos detalhados",
-    "Update needed" : "É necessário atualizar",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Para obter ajuda, consulte a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está atualmente no modo de manutenção, o que poderá demorar algum tempo.",
     "This page will refresh itself when the %s instance is available again." : "Esta página irá ser atualizada quando a instância %s ficar novamente disponível."
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
