@@ -172,7 +172,6 @@ OC.L10N.register(
     "Share to Twitter. Opens in a new window." : "Objavi povezavo na Twitter (odpre v novem oknu).",
     "Share to Facebook. Opens in a new window." : "Objavi povezavo na Facebook (odpre se v novem oknu).",
     "Share to Diaspora. Opens in a new window." : "Objavi povezavo na Diasporo (odpre v novem oknu).",
-    "Share to Google+. Opens in a new window." : "Objavi povezavo na Google+ (odpre v novem oknu).",
     "Share via email. Opens your mail client." : "Objavi povezavo prek elektronske pošte (odpre v oknu odjemalca).",
     "Email link to person" : "Posreduj povezavo po elektronski pošti",
     "Send link via email" : "Pošlji povezavo prek elektronske pošte",
@@ -199,16 +198,14 @@ OC.L10N.register(
     "Public Links" : "Javne povezave",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Souporaba z uporabniki, ki so na drugih oblakih ownCloud s povezavo uporabnik@domena.si/owncloud",
     "Share with users…" : "Omogoči souporabo z ...",
-    "Share with users, groups or remote users…" : "Souporaba z uporabniki, skupinami ali zunanjimi uporabniki ...",
     "Share with users or groups…" : "Souporaba z uporabniki ali skupinami ...",
-    "Share with users or remote users…" : "Souporaba z uporabniki ali oddaljenimi uporabniki ...",
     "Error removing share" : "Napaka odstranjevanja souporabe",
     "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
     "restricted" : "omejeno",
     "invisible" : "nevidno",
     "({scope})" : "({scope})",
-    "Delete" : "Izbriši",
     "Rename" : "Preimenuj",
+    "Delete" : "Izbriši",
     "Collaborative tags" : "Oznake za sodelovalno souporabo",
     "The object type is not specified." : "Vrsta predmeta ni podana.",
     "Enter new" : "Vnesite novo",
@@ -271,13 +268,11 @@ OC.L10N.register(
     "Database name" : "Ime podatkovne zbirke",
     "Database tablespace" : "Razpredelnica podatkovne zbirke",
     "Database host" : "Gostitelj podatkovne zbirke",
-    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Določiti je treba številko vrat skupaj z imenom gostitelja (na primer: localhost: 5432).",
     "Performance warning" : "Opozorilo učinkovitosti delovanja",
     "SQLite will be used as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite",
     "For larger installations we recommend to choose a different database backend." : "Za večje namestitve je priporočljivo uporabiti drugo ozadnji program  zbirke podatkov.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Uporaba SQLite ni priporočljiva iz varnostnih razlogov, še posebej če se sistem krajevno usklajuje z namizjem prek odjemalca.",
     "Finish setup" : "Končaj nastavitev",
-    "Finishing …" : "Poteka zaključevanje opravila ...",
     "Need help?" : "Ali potrebujete pomoč?",
     "See the documentation" : "Preverite dokumentacijo",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Pozdravljeni,<br><br>uporabnik %s vam je omogočil souporabo <strong>%s</strong>.<br><a href=\"%s\">Oglejte si vsebino!</a><br><br>",
@@ -285,6 +280,7 @@ OC.L10N.register(
     "Menu" : "Meni",
     "Log out" : "Odjava",
     "Search" : "Poišči",
+    "You are trying to access a private link. Please log in first." : "Poskušate odpreti zasebno povezavo. Pred nadaljevanjem se je treba prijaviti.",
     "Server side authentication failed!" : "Overitev s strežnika je spodletela!",
     "Please contact your administrator." : "Stopite v stik s skrbnikom sistema.",
     "An internal error occurred." : "Prišlo je do notranje napake.",
@@ -293,13 +289,11 @@ OC.L10N.register(
     "Username or email" : "Uporabniško ime ali elektronski naslov",
     "Wrong password. Reset it?" : "Napačno geslo. Ali ga želite ponastaviti?",
     "Wrong password." : "Napačno geslo!",
-    "You are trying to access a private link. Please log in first." : "Poskušate odpreti zasebno povezavo. Pred nadaljevanjem se je treba prijaviti.",
     "Stay logged in" : "Ohrani prijavo",
     "Alternative Logins" : "Druge prijavne možnosti",
     "Use the following link to reset your password: {link}" : "Za ponastavitev gesla uporabite povezavo: {link}",
     "Password changed successfully" : "Geslo je uspešno spremenjeno",
     "New password" : "Novo geslo",
-    "New Password" : "Novo geslo",
     "Reset password" : "Ponastavi geslo",
     "This ownCloud instance is currently in single user mode." : "Ta seja oblaka ownCloud je trenutno v načinu enega sočasnega uporabnika.",
     "This means only administrators can use the instance." : "To pomeni, da lahko oblak uporabljajo le osebe s skrbniškimi dovoljenji.",
@@ -310,7 +304,6 @@ OC.L10N.register(
     "Cancel login" : "Prekliči prijavo",
     "Please authenticate using the selected factor." : "Overite z uporabo izbranega faktorja.",
     "An error occurred while verifying the token" : "Prišlo je do napake med preverjanjem žetona",
-    "You are accessing the server from an untrusted domain." : "Trenutno je vzpostavljena povezava s strežnikom prek ne-varne domene.",
     "App update required" : "Zahtevana je posodobitev programa",
     "%s will be updated to version %s" : "%s bo posodobljen na različico %s.",
     "These apps will be updated:" : "Posodobljeni bodo naslednji vstavki:",
@@ -319,7 +312,6 @@ OC.L10N.register(
     "Start update" : "Začni posodobitev",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Za razreševanje časovnih zahtev večjih namestitev lahko uporabite ukaz iz namestitvene mape:",
     "Detailed logs" : "Podrobni dnevniški zapisi",
-    "Update needed" : "Zahtevana je posodobitev",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Za več podrobnosti si oglejte <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentacijo</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v načinu vzdrževanja, kar lahko traja.",
     "This page will refresh itself when the %s instance is available again." : "Stran bo osvežena ko bo %s spet na voljo."
