@@ -33,9 +33,10 @@ use OCP\IRequest;
 use OCP\ILogger;
 use OCP\ISession;
 use OCP\IUser;
+use OCP\IGroupManager;
 
 class Manager {
-	const SESSION_UID_KEY = 'two_factor_auth_uid';
+	public const SESSION_UID_KEY = 'two_factor_auth_uid';
 
 	/** @var AppManager */
 	private $appManager;
@@ -43,6 +44,9 @@ class Manager {
 	/** @var ISession */
 	private $session;
 
+	/** @var IGroupManager */
+	private $groupManager;
+
 	/** @var IConfig */
 	private $config;
 
@@ -55,13 +59,15 @@ class Manager {
 	/**
 	 * @param AppManager $appManager
 	 * @param ISession $session
+	 * @param IGroupManager $groupManager
 	 * @param IConfig $config
 	 * @param IRequest $request
 	 * @param ILogger $logger
 	 */
-	public function __construct(AppManager $appManager, ISession $session, IConfig $config, IRequest $request, ILogger $logger) {
+	public function __construct(AppManager $appManager, ISession $session, IGroupManager $groupManager, IConfig $config, IRequest $request, ILogger $logger) {
 		$this->appManager = $appManager;
 		$this->session = $session;
+		$this->groupManager = $groupManager;
 		$this->config = $config;
 		$this->request = $request;
 		$this->logger = $logger;
@@ -74,10 +80,29 @@ class Manager {
 	 * @return boolean
 	 */
 	public function isTwoFactorAuthenticated(IUser $user) {
+		if ($this->isTwoFactorEnforcedForUser($user)) {
+			return \count($this->getProviders($user)) > 0;
+		}
 		$twoFactorEnabled = ((int) $this->config->getUserValue($user->getUID(), 'core', 'two_factor_auth_disabled', 0)) === 0;
 		return $twoFactorEnabled && \count($this->getProviders($user)) > 0;
 	}
 
+	public function isTwoFactorEnforcedForUser(IUser $user) {
+		if ($this->config->getAppValue('core', 'enforce_2fa', 'no') !== 'yes') {
+			return false;
+		}
+
+		$enforce2faExcludedGroups = \json_decode($this->config->getAppValue('core', 'enforce_2fa_excluded_groups', '[]'), true);
+		if (!empty($enforce2faExcludedGroups)) {
+			foreach ($enforce2faExcludedGroups as $group) {
+				if ($this->groupManager->isInGroup($user->getUID(), $group)) {
+					return false;
+				}
+			}
+		}
+		return true;
+	}
+
 	/**
 	 * Disable 2FA checks for the given user
 	 *
@@ -135,6 +160,14 @@ class Manager {
 			}
 		}
 
+		// if 2-factor is enforced, we must not filter out providers that
+		// might not be enabled or configured. The providers are expected
+		// to handle this problem on their own, usually by allowing
+		// configuration (at least partially) in the challenge page.
+		if ($this->isTwoFactorEnforcedForUser($user)) {
+			return $providers;
+		}
+
 		return \array_filter($providers, function ($provider) use ($user) {
 			/* @var $provider IProvider */
 			return $provider->isTwoFactorAuthEnabledForUser($user);
@@ -170,8 +203,10 @@ class Manager {
 		if ($result) {
 			$this->session->remove(self::SESSION_UID_KEY);
 		} else {
-			$this->logger->warning("Two factor verify failed: '{$user->getUserName()}' (Remote IP: '{$this->request->getRemoteAddress()}')",
-				['app' => 'core']);
+			$this->logger->warning(
+				"Two factor verify failed: '{$user->getUserName()}' (Remote IP: '{$this->request->getRemoteAddress()}')",
+				['app' => 'core']
+			);
 		}
 		return $result;
 	}
