@@ -23,7 +23,6 @@ OC.L10N.register(
     "Couldn't change the email address because the user does not exist" : "Não foi possível alterar o endereço de correio eletrónico porque o utilizador não existe",
     "Couldn't change the email address because the token is invalid" : "Não foi possível alterar o endereço de correio eletrónico porque a senha é inválida",
     "Your %s account was created" : "A sua conta %s foi criada",
-    "Invalid mail address" : "Endereço de e-mail inválido",
     "A user with that name already exists." : "Já existe um utilizador com esse nome.",
     "Unable to create user." : "Não é possível criar o utilizador.",
     "Unable to delete user." : "Não é possível eliminar o utilizador.",
@@ -33,6 +32,7 @@ OC.L10N.register(
     "Email has been changed successfully." : "O endereço de correio eletrónico foi alterado com sucesso.",
     "An email has been sent to this address for confirmation. Until the email is verified this address will not be set." : "Foi enviada uma mensagem para este endereço para confirmação. Até que o correio eletrónico seja verificado, este endereço não será definido.",
     "No email was sent because you already sent one recently. Please try again later." : "Não foi enviada nenhuma mensagem porque já foi enviada uma recentemente. Por favor, tente novamente mais tarde.",
+    "Unable to change display name" : "Não foi possível alterar o nome",
     "Your full name has been changed." : "O seu nome completo foi alterado.",
     "Unable to change full name" : "Não é possível alterar o nome completo",
     "%s email address confirm" : "Confirmação de endereço de correio eletrónico de %s",
@@ -40,6 +40,7 @@ OC.L10N.register(
     "%s email address changed successfully" : "O endereço de e-mail de %s foi alterado com sucesso",
     "Couldn't send email address change notification mail. Please contact your administrator." : "Não foi possível enviar a mensagem de notificação da alteração do endereço de e-mail. Por favor, contacte o seu administrador.",
     "Unable to enable/disable user." : "Não é possível ativar/desativar o utilizador.",
+    "Invalid mail address" : "Endereço de e-mail inválido",
     "Create" : "Criar",
     "Change" : "Alterar",
     "Delete" : "Eliminar",
@@ -100,12 +101,9 @@ OC.L10N.register(
     "Unable to delete {objName}" : "Não é possível eliminar {objNome}",
     "Error creating group: {message}" : "Erro ao criar o grupo: {message}",
     "A valid group name must be provided" : "Deve ser indicado um nome de grupo válido",
-    "deleted {groupName}" : "{groupName} eliminado",
-    "undo" : "anular",
     "Delete group" : "Eliminar grupo",
     "never" : "nunca",
-    "deleted {userName}" : "{userName} eliminado",
-    "add group" : "adicionar grupo",
+    "unknown" : "desconhecido",
     "Invalid quota value \"{val}\"" : "Valor de quota inválido \"{val}\"",
     "enabled" : "ativado",
     "disabled" : "desativado",
@@ -224,7 +222,6 @@ OC.L10N.register(
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Só-de-Leitura foi ativada. Isto evita definir algumas configurações através da interface da Web. Além disso, o ficheiro precisa de ser definido gravável manualmente para cada atualização.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "O PHP está aparentemente configurado para remover blocos doc em linha. Isto vai tornar inacessíveis várias aplicações básicas.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto é provavelmente causado por uma cache/acelerador como o Zend OPcache or eAcelerador.",
-    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "A base de dados não tem o nível de isolamento da transacção \"READ COMMITTED\" activado. Isto pode causar problemas quando várias acções são executadas em paralelo.",
     "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s abaixo da versão %2$s está instalado. Por motivos de estabilidade e desempenho, recomendamos que atualize para a nova versão %1$s.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "O Módulo PHP 'fileinfo' não se encontra instalado/activado. É fortemente recomendado que active este módulo para obter os melhores resultado com a detecção dos tipos de mime.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Bloqueio de arquivos transacionais está desativado, isto poderá levar a problemas com condições de corrida. Ative 'filelocking.enabled' no config.php para evitar estes problemas. Consulte a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação ↗</a> para mais informação.",
@@ -251,7 +248,6 @@ OC.L10N.register(
     "Desktop client" : "Cliente Desktop",
     "Android app" : "Aplicação Android",
     "iOS app" : "Aplicação iOS",
-    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Se quer apoiar o projecto\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">junte-se ao desenvolvimento</a>\n\t\tou\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">espalhe a palavra</a>!",
     "Show First Run Wizard again" : "Mostrar novamente o «Assistente de Arranque Inicial»",
     "Domain" : "Domínio",
     "Add" : "Adicionar",
@@ -272,6 +268,7 @@ OC.L10N.register(
     "For password recovery and notifications" : "Para recuperação da palavra-passe e notificações",
     "No email address set" : "Nenhum endereço de email estabelecido",
     "You are member of the following groups:" : "Você é membro dos seguintes grupos:",
+    "Username" : "Nome de utilizador",
     "Password" : "Palavra-passe",
     "Unable to change your password" : "Não é possível alterar a sua palavra-passe",
     "Current password" : "Palavra-passe atual",
@@ -287,10 +284,9 @@ OC.L10N.register(
     "Name" : "Nome",
     "App name" : "Nome da app",
     "Use the credentials below to configure your app or device." : "Use as credenciais abaixo para configurar a sua app ou dispositivo",
-    "Username" : "Nome de utilizador",
     "Done" : "Concluído",
     "Version" : "Versão",
-    "New Password" : "Nova palavra-passe",
+    "Set password" : "Defina a senha",
     "Personal" : "Pessoal",
     "Admin" : "Administração",
     "Settings" : "Definições",
@@ -321,4 +317,4 @@ OC.L10N.register(
     "change email address" : "alterar endereço de correio eletrónico",
     "Default" : "Predefinição"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
